SystemOrganization addCategory: #'Settings-Polymorph'!

Object subclass: #PSMCSystemSettings
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Settings-Polymorph'!

!PSMCSystemSettings class methodsFor: 'settings' stamp: 'AlainPlantec 1/10/2010 22:04'!
defaultMonticelloDiffToolsSettingOn: aBuilder
	<systemsettings>  
	(aBuilder setting: #polymorphDiffToolsUsedByDefault)
		label: 'Use Polymorph difference tools' translated;
		description: 'When enabled the Polymorph diff tools will be used with Monticello. When disabled, the original tools are used.' translated;
		parent: #monticello;
		target: PSMCPatchMorph;
		selector: #usedByDefault! !

Object subclass: #PolymorphSystemSettings
	instanceVariableNames: ''
	classVariableNames: 'DesktopColor DesktopGradientDirection DesktopGradientFillColor DesktopGradientOrigin DesktopImageFileName DesktopLogo DesktopLogoFileName ShowDesktopLogo UseDesktopGradientFill'
	poolDictionaries: ''
	category: 'Settings-Polymorph'!

PolymorphSystemSettings class
	instanceVariableNames: 'usePolymorphDiffMorph'!

!PolymorphSystemSettings commentStamp: 'LaurentLaffont 3/15/2011 20:46' prior: 0!
I provide settings for Morphic appearance (theme, fonts, colors, ...) that can be found and changed in the Settings browser.!

PolymorphSystemSettings class
	instanceVariableNames: 'usePolymorphDiffMorph'!

!PolymorphSystemSettings class methodsFor: 'settings' stamp: 'AlainPlantec 9/17/2011 18:53'!
appearanceSettingsOn: aBuilder 
	<systemsettings>
	(aBuilder group: #appearance)
		label: 'Appearance' translated;  
		description: 'All settings concerned with the look''n feel of your system' translated;
		with: [
			(aBuilder pickOne: #uiThemeClass)
				label: 'User interface theme' translated;
				target: self;
				default: UITheme standardThemeClass;
				order: 1;
				domainValues: self uiThemeClassChoices.
			self morphicSettingsOn: aBuilder.
			self desktopSettingsOn: aBuilder.
			self soundSettingsOn: aBuilder]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 5/13/2011 09:20'!
desktopBackgroundChanged
	| fill |
	self desktopImageFileName
		ifEmpty: [UIManager default currentWorld world backgroundMorph: nil]
		ifNotEmpty: [^ [Form setBackgroundFromImageFileNamed: self desktopImageFileName]
				on: Error
				do: []].
	self useDesktopGradientFill
		ifTrue: [World fillStyle isGradientFill
				ifTrue: [fill := World fillStyle]
				ifFalse: [fill := GradientFillStyle new].
			fill colorRamp: {0.0 -> self desktopColor darker. 1.0 -> self desktopGradientFillColor lighter}.
			fill origin: (World perform: self desktopGradientOrigin).
			self desktopGradientDirection = #Vertical
				ifTrue: [fill radial: false.
					fill normal: World width @ 0.
					fill direction: 0 @ World height].
			self desktopGradientDirection = #Horizontal
				ifTrue: [fill radial: false.
					fill normal: 0 @ World height.
					fill direction: World width @ 0]. 
			self desktopGradientDirection = #Radial
				ifTrue: [
					fill radial: true.
					self desktopGradientOrigin = #center
						ifTrue: [fill direction: World width // 2 @ 0.
							fill normal: 0 @ (World height // 2)]
						ifFalse: [fill direction: World width @ 0.
							fill normal: 0 @ World height]].
			World fillStyle: fill]
		ifFalse: [World color: self desktopColor].
		World changed! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 1/10/2010 09:37'!
desktopColor
	^ DesktopColor ifNil: [DesktopColor := World defaultWorldColor] ! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 15:50'!
desktopColor: aColor
	DesktopColor := aColor.
	self desktopBackgroundChanged! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/11/2011 07:31'!
desktopColorSettingsOn: aBuilder 
	(aBuilder setting: #desktopColor) label: 'Color';
		 description: 'This is the only color of your desktop if no gradient is used. If you make use of a gradient, then this color is the first one of the gradient' translated;
		with: [(aBuilder setting: #useDesktopGradientFill) label: 'Gradient';
				 description: 'If true, then more settings will be available in order to define the desktop background color gradient';
				 noOrdering;
				with: [(aBuilder setting: #desktopGradientFillColor) label: 'Other color';
						 description: 'This is the second color of your gradient (the first one is given by the "Color" setting' translated.
					(aBuilder pickOne: #desktopGradientDirection) label: 'Direction';
						 domainValues: {#Horizontal. #Vertical. #Radial}.
					(aBuilder pickOne: #desktopGradientOrigin) label: 'Origin';
						 domainValues: {
							'Top left' translated -> #topLeft. 
							'Top' translated -> #topCenter. 
							'Top right' translated -> #topRight. 
							'Right' translated -> #rightCenter. 
							'Bottom right' translated -> #bottomRight. 
							'Bottom' translated -> #bottomCenter. 
							'Bottom left' translated -> #bottomLeft. 
							'Left' translated -> #leftCenter. 
							'Center' translated -> #center}]]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/30/2009 06:33'!
desktopGradientDirection
	"#Radial #Vertical or #Horizontal"
	^ DesktopGradientDirection ifNil: [DesktopGradientDirection := #Vertical]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 15:50'!
desktopGradientDirection: aSymbol
	"#Radial #Vertical or #Horizontal"
	DesktopGradientDirection := aSymbol.
	self desktopBackgroundChanged
! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/30/2009 06:32'!
desktopGradientFillColor
	^ DesktopGradientFillColor ifNil: [DesktopGradientFillColor := self desktopColor]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 15:50'!
desktopGradientFillColor: aColor 
	DesktopGradientFillColor := aColor.
	self desktopBackgroundChanged! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/30/2009 06:37'!
desktopGradientOrigin
	"#topLeft #topCenter #topRight #rightCenter #bottomRight #bottomCenter #bottomLeft #leftCenter #center"
	^ DesktopGradientOrigin ifNil: [DesktopGradientOrigin := #topLeft]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 16:10'!
desktopGradientOrigin: aSymbol
	"#Radial #Vertical or #Horizontal"
	DesktopGradientOrigin := aSymbol.
	self desktopBackgroundChanged
! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 12:00'!
desktopImageFileName
	^ DesktopImageFileName ifNil: [DesktopImageFileName := '']! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 15:47'!
desktopImageFileName: aFileName
	DesktopImageFileName := aFileName.
	self desktopBackgroundChanged! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/11/2011 07:15'!
desktopLogo
	^ DesktopLogo ifNil: [self showDesktopLogo ifTrue: [DesktopLogo := self pharoLogo]]	! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/11/2011 07:16'!
desktopLogo: anImageMorph
	DesktopLogo := anImageMorph! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/11/2011 08:08'!
desktopLogoChanged
	self showDesktopLogo
		ifFalse: [self setDesktopLogoWith: nil.
			^ self].
	self desktopLogoFileName
		ifEmpty: [self setDesktopLogoWith: self pharoLogo]
		ifNotEmpty: [[self
				setDesktopLogoWith: (ImageMorph withForm: (Form fromFileNamed: self desktopLogoFileName))]
				on: Error
				do: [self setDesktopLogoWith: self pharoLogo]].
! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/11/2011 07:40'!
desktopLogoFileName
	^ DesktopLogoFileName ifNil: [DesktopLogoFileName := '']! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/11/2011 07:43'!
desktopLogoFileName: aFileName
	DesktopLogoFileName = aFileName ifTrue: [^ self].
	DesktopLogoFileName := aFileName.
	self desktopLogoChanged ! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/14/2011 08:24'!
desktopSettingsOn: aBuilder 
	(aBuilder group: #desktopSettings)
		label: 'Desktop';
		target: self;
		noOrdering;
		with: [
			(aBuilder setting: #showDesktopLogo)
				label: 'Show logo' translated;
				description: 'If true, then a logo if shown on the top left of the desktop' translated;
				with: [
					(aBuilder setting: #desktopLogoFileName)
						type: #FilePath;
						description: 'The path of an image file for your own logo, the default pharo logo is used if empty.' translated;
						label: 'Logo image file name'].
			self desktopColorSettingsOn: aBuilder.
			(aBuilder setting: #desktopImageFileName)
				type: #FilePath;
				description: 'The path of an image file which will be imported as a form and displayed as your desktop background' translated;
				label: 'Desktop background image file name']
						! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 1/10/2010 09:29'!
morphicAnimationSettingsOn: aBuilder 
	(aBuilder setting: #useAnimation)
		label: 'Animation' translated;
		target: UITheme;
		targetSelector: #currentAnimationSettings;
		description: 'If true, some animations will be use when opening and closing windows' translated;
		noOrdering;
		with: [
			(aBuilder setting: #animateClosing)
				label: 'Animate closing' translated;
				description: 'If true, then windows closing is animated' translated.
			(aBuilder range: #animationDelay) 
				label: 'Delay' translated;
				description: 'The delay between each step of the window animation in milliseconds.' translated;
				selector: #delay;
				range: (0 to: 30).
			(aBuilder range: #animationNumberOfSteps) 
				label: 'Number of steps' translated;
				description: 'The number of steps in the window animation.' translated;
				selector: #numberOfSteps;
				range: (0 to: 100).
		]! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 1/10/2010 09:30'!
morphicHaloSettingsOn: aBuilder 
	(aBuilder group: #halo)
		label: 'Halo' translated;
		parent: #morphic;
		description: 'All halo settings' translated;
		noOrdering;
		with: [
			(aBuilder setting: #haloEnclosesFullBounds)
				label: 'Encloses fullbounds' translated;
				target: HaloMorph;
				description: 'If true, halos will enclose the full bounds of the target Morph, rather than just the bounds' translated.
			(aBuilder setting: #showBoundsInHalo)
				label: 'Exhibits bounds' translated;
				target: HaloMorph;
				description: 'If true, halos will include a fine rectangle around the bounds of the target morph.' translated
		]! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 2/11/2011 21:09'!
morphicMenuSettingsOn: aBuilder 
	(aBuilder group: #menu)
		label: 'Menu' translated;
		parent: #morphic;
		description: 'All menu settings' translated;
		target: UITheme;
		targetSelector: #currentSettings;
		noOrdering;
		with: [
			(aBuilder setting: #preferGradientFill)
				label: 'Gradient filling' translated;
				description: 'If true, then menus will have a gradient look' translated.
			(aBuilder setting: #flatMenu)
				label: 'Flat appearance' translated;
				description: 'If true, then menu will without 3D like borders.' translated.
			(aBuilder setting: #autoMenuColor)
				label: 'Computed color' translated;
				description: 'If true, then the menu color will be computed from world dressing.' translated.
			(aBuilder setting: #menuColor)
				label: 'Menu color' translated;
				description: 'The menu color to use if it is not computed automatically (see the ''Computed color'' setting)' translated.
			(aBuilder setting: #menuSelectionColor)
				label: 'Menu selection color' translated;
				description: 'The background color of a selected menu item' translated.
			(aBuilder setting: #menuSelectionTextColor)
				description: 'The text color of a selected menu item' translated;
				label: 'Menu selection text color' translated.
			(aBuilder setting: #menuWithIcons)
				label: 'Automatically added icons' translated;
				description: 'If true, then menu item will be decorated with automatically found icons.' translated.
		]! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 9/17/2011 18:53'!
morphicSettingsOn: aBuilder 
	(aBuilder group: #morphic)
		label: 'Morphic' translated;
		description: 'All morphic settings' translated;
		noOrdering;
		with: [
			self morphicWindowsSettingsOn: aBuilder.
			self morphicMenuSettingsOn: aBuilder.
			self morphicHaloSettingsOn: aBuilder.
			self morphicAnimationSettingsOn: aBuilder.
			(aBuilder setting: #keyboardFocusOnMouseDown)
				label: 'Keyboard focus on mouse down' translated;
				target: MorphicModel;
				description: 'When enabled the mouse button must be clicked within a morph for it to take the keyboard focus.' translated.
			(aBuilder setting: #mouseOverForKeyboardFocus)
				label: 'Lose keyboard focus when mouse leave' translated;
				target: MorphicModel;
				description: 'When true, the mouse must be over a text or list pane in morphic for keystrokes to be felt, and when the mouse is out over the desktop, the so-called desktop-command-keys, such as cmd-b and cmd-R, are honored.  When false, list panes and text panes in morphic remain sensitive to keystrokes even after the mouse is no longer over the pane.' translated.
			(aBuilder setting: #showTextEditingState)
				label: 'Show text editing state' translated;
				target: PluggableTextMorph;
				description: 'When enabled the editing state of PluggableTextMorphs is shown as a colored inset border.' translated.
			(aBuilder setting: #balloonHelpEnabled)
				label: 'Balloon help'; 
				target: UITheme;
				targetSelector: #currentSettings.
			(aBuilder setting: #editableStringMorph)
				label: 'String morphs are editable' translated;
				target: StringMorph;
				description: 'If true, editing on StringMorph is possible if the shift key is pressed while selecting the morphs.' translated.
			(aBuilder setting: #defaultYellowButtonMenuEnabled)
				label: 'Show default action click menu' translated;
				target: Morph;
				description: 'If true, populate an action click menu (default context menu).' translated.
			(aBuilder setting: #easySelectingWorld)
				label: 'Easy selection' translated;
				target: WorldState;
				description: 'If true, select multiple Morphs in the world by dragging a selection box around them.' translated.
			(aBuilder setting: #usePolymorphDiffMorph)
				label: 'Use Polymorph DiffMorph' translated;
				target: self;
				default: true ;
				description: 'If true,  whenever requested the Polymorph DiffMorph will be used for comparison of two methods' translated ].	 ! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 10/20/2010 20:56'!
morphicWindowsSettingsOn: aBuilder 
	(aBuilder group: #windows)
		label: 'Windows' translated;
		description: 'All windows settings' translated;
		noOrdering;
		with: [
			(aBuilder setting: #windowColor)
				target: UITheme;
				targetSelector: #currentSettings;
				label: 'Window color' translated;
				description: 'The window color' translated.
			(aBuilder setting: #preferRoundCorner)
				target: UITheme;
				targetSelector: #currentSettings;
				label: 'Rounded corners' translated;
				description: 'If true, then windows, menu and other popups will have their corners rounded.' translated.
			(aBuilder range: #fullScreenMargin) 
						target: SystemWindow;
						label: 'Full screen margin' translated;
						description: 'Specify the amount of space that is let around a windows when it''s opened fullscreen' translated;
						range: (-5 to: 100).
			(aBuilder setting: #fadedBackgroundWindows)
				target: UITheme;
				targetSelector: #currentSettings;
				label: 'Fade background windows' translated;
				description: 'If true then, background windows appear more "washed out" to distinguish from the active window' translated.
			(aBuilder setting: #fastDragging)
				target: UITheme;
				targetSelector: #currentSettings;
				label: 'Fast dragging' translated;
				description: 'If true, window drag will be done by dragging an outline of the window instead of the whole window. It is very convenient on a slow machine' translated.
			(aBuilder range: #textEntryFieldMinimumWidth)
				label: 'Text entry dialog width' translated;
				target: TextEntryDialogWindow;
				selector: #minimumWidth;
				range: (100 to: 800);
				description: 'Set the default text field width of the text entry dialog window' translated]
			
			
			
! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/11/2011 07:15'!
pharoLogo
	^ ImageMorph withForm: self pharoLogoForm! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/11/2011 07:03'!
pharoLogoContents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAXcAAACHCAYAAADtJRlTAAC8WUlEQVR4XuWddUAcSdP/d3D3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=='! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/11/2011 07:04'!
pharoLogoForm
	^ Form fromBinaryStream: self pharoLogoContents base64Decoded asByteArray readStream! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/11/2011 08:06'!
setDesktopLogoWith: aMorph
	self desktopLogo ifNotNil: [self desktopLogo delete].
	self desktopLogo: aMorph.
	self desktopLogo ifNotNil: [self desktopLogo openInWorld; beSticky; lock; goBehind]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/11/2011 07:05'!
showDesktopLogo
	^ ShowDesktopLogo ifNil: [ShowDesktopLogo := true]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 9/11/2011 07:24'!
showDesktopLogo: aBoolean
	ShowDesktopLogo = aBoolean ifTrue: [^ self].
	ShowDesktopLogo := aBoolean.
	self desktopLogoChanged! !

!PolymorphSystemSettings class methodsFor: 'sound' stamp: 'HenrikSperreJohansen 1/21/2011 14:20'!
soundSettingsOn: aBuilder
	(aBuilder setting: #soundEnabled)
		label: 'Sound'; 
		target: SoundService;
		noOrdering;
		with: [
			(aBuilder setting: #useThemeSounds)
				label: 'Use theme sounds';
				target: SoundTheme; 
				with: [
					(aBuilder pickOne: #soundThemeClass)
						label: 'Sound theme' translated;
						target: self;
						domainValues: self soundThemeClassChoices]]! !

!PolymorphSystemSettings class methodsFor: 'sound' stamp: 'AlainPlantec 1/10/2010 07:54'!
soundThemeClass
	^ SoundTheme current class
! !

!PolymorphSystemSettings class methodsFor: 'sound' stamp: 'AlainPlantec 1/10/2010 07:54'!
soundThemeClass: aSoundThemeClass
	aSoundThemeClass ifNil: [^ self].
	self soundThemeClass ~= aSoundThemeClass
		ifTrue: [aSoundThemeClass beCurrent]! !

!PolymorphSystemSettings class methodsFor: 'sound' stamp: 'AlainPlantec 1/10/2010 07:54'!
soundThemeClassChoices
	^ SoundTheme allThemeClasses collect: [:c | c themeName -> c]! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 12/10/2009 16:04'!
uiThemeClass
	^ UITheme current class
! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 2/11/2011 18:42'!
uiThemeClass: aUIThemeClass
	| themeClass |
	themeClass := aUIThemeClass 
		ifNil: [ UITheme standardThemeClass ].
	themeClass beCurrent! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 12/10/2009 16:02'!
uiThemeClassChoices
	^ UITheme allThemeClasses collect: [:c | c themeName -> c]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/30/2009 06:31'!
useDesktopGradientFill
	^ UseDesktopGradientFill ifNil: [UseDesktopGradientFill := false]! !

!PolymorphSystemSettings class methodsFor: 'desktop' stamp: 'AlainPlantec 11/28/2009 15:49'!
useDesktopGradientFill: aBoolean 
	UseDesktopGradientFill := aBoolean.
	self desktopBackgroundChanged! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'CarloTeixeira 5/23/2011 15:47'!
usePolymorphDiffMorph
	^ usePolymorphDiffMorph ifNil: [usePolymorphDiffMorph := false.]! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'FernandoOlivero 3/30/2011 16:14'!
usePolymorphDiffMorph: aBoolean
	usePolymorphDiffMorph := aBoolean! !

!PolymorphSystemSettings class methodsFor: 'morphic' stamp: 'AlainPlantec 2/25/2011 15:59'!
windowPositionStrategySettingsOn: aBuilder
	<systemsettings>
	(aBuilder pickOne: #usedStrategy) 
		label: 'Window position strategy' translated;
		parent: #windows;
		target: RealEstateAgent;
		domainValues: {'Reverse Stagger' translated -> #staggerFor:initialExtent:world:. 'Cascade' translated -> #cascadeFor:initialExtent:world:. 'Standard' translated -> #standardFor:initialExtent:world:};
		description: 'If Reversed Stagger, windows are placed in free space,
if Cascade, windows are placed in cascade based on current active window or based on cursor position.' translated.! !

Object subclass: #TaskListSystemSettings
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Settings-Polymorph'!

!TaskListSystemSettings class methodsFor: 'settings' stamp: 'BenjaminVanRyseghem 9/26/2011 03:07'!
taskListSettingOn: aBuilder
	<systemsettings> 
	(aBuilder setting: #keepTaskListOpen)
		label: 'Keep task list open' translated;
		description: 'Whether the tasklist is closed (and the selected window activated) when the command key is released' translated;
		parent: #morphic;
		selector: #keepOpen;
		target: TasklistMorph.
		
	(aBuilder setting: #useHistoricalShortcuts)
		label: 'Use historical shortcuts' translated;
		description: 'If chosen, the shortcuts are cmd-left, cmd-right. If not, they are ctrl-shift-tab, ctrl-tab' translated;
		parent: #morphic;
		selector: #useHistoricalShortcuts;
		target: TasklistMorph.! !

Object subclass: #TaskbarSystemSettings
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Settings-Polymorph'!

!TaskbarSystemSettings class methodsFor: 'settings' stamp: 'AlainPlantec 12/15/2009 10:04'!
taskbarSettingOn: aBuilder
	<systemsettings>
	(aBuilder setting: #showTaskbar)
		target: TaskbarMorph;
		parent: #morphic;
		label: 'Taskbar' translated;
		description: 'Whether the world''s taskbar should be shown or not.' translated;
		with: [
			(aBuilder setting: #showWindowPreview)
				label: 'Window preview' translated;
				description: 'Whether the world''s taskbar buttons should show previews of the associated window while the mouse is over them.' translated
		]! !
